@@ -5,7 +5,7 @@ import tarfile
 import zipfile
 from time import sleep
 
-version = "0.0.34"
+version = "0.0.36"
 
 try:
     from uuid import uuid4
@@ -157,7 +157,7 @@ def _make_homepage():
         "</style>"
         "</head><body>"
         "{}"
-        "</body></html>"
+        "<footer>Circe " + version + "</footer></body></html>"
     )
     try:
         working_directory = os.path.dirname(os.path.abspath(__file__))
